# sap-simulation-package

Creating a python package to simulate games of super auto pets

Using this to practice TDD, developing and distributing a python package to pypi, and eventually developing a bot for the game
